# Generated by Django 5.2.4 on 2025-07-15 21:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('logq', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='logentry',
            name='function',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='logentry',
            name='line_number',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='logentry',
            name='module',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]
